// jshint maxerr:1000
/* ---------------------------------------------------------------------------------------------------------

    SCRIBBLEMAKES - INTERACTIVE MAP WIDGET
    --------------------------------------
    Last updated: 7th August 2023
    
    Welcome to the Interactive Map Widget (IMW)! This widget creates an image map that you can use to make
      'rooms' inside your website. To integrate into your website, save this .js file to it and follow the
      instructions in the 'more information' link (https://scribblemakes.com/code/development#sc_imw). 
      You will need to fill in the required variables below.
      
    To include this correctly in your web page, you can copy this html code between your <body> tags:
    ---------------------------------------------------------------------------------------- Start HTML Code
    <div id="sc_imw_container">
      <img id="sc_imw_mappedImage" src="sc_imw_imgs/sc_imw_testingRoom1.png" usemap="#sc_imw_testingRoom1.png"  alt="Scribblemakes Code Interactive Image Map Widget">
      <noscript>Javascript is disabled. Enable your Javascript to use the interactive map.</noscript>
          
      <!-- First Map (Room 1) -->
      <map name="sc_imw_testingRoom1.png">
        <area shape="rect" coords="261,202,547,803" 
          onmouseenter="sc_imw_AreaHover('sc_imw_testingRoomHoverLeft.png')"
          href=""
          class="sc_imw_MapClass">
        <area shape="rect" coords="1370,202,1658,803" 
          onmouseenter="sc_imw_AreaHover('sc_imw_testingRoomHoverRight.png')"
          onclick="sc_imw_changeArea('sc_imw_testingRoom2.png')"
          class="sc_imw_MapClass">
      </map>       
      <!-- Second Map (Room 2) -->
      <map name="sc_imw_testingRoom2.png">
        <area shape="rect" coords="261,202,547,803" 
          onmouseenter="sc_imw_AreaHover('sc_imw_testingRoomHoverLeft.png')"
          onclick="sc_imw_changeArea('sc_imw_testingRoom1.png')"
          class="sc_imw_MapClass">
        <area shape="rect" coords="820,226,1098,807" 
          onmouseenter="sc_imw_AreaHover('sc_imw_testingRoom2HoverDoor.png')"
          href="https://scribblemakes.com/code/development#sc_imw"
          class="sc_imw_MapClass">
        <area shape="rect" coords="1370,202,1658,803" 
          onmouseenter="sc_imw_AreaHover('sc_imw_testingRoomHoverRight.png')"
          href=""
          class="sc_imw_MapClass">
      </map>
    </div>
    <!-- Link and Button (optional)
    <a id="sc_imw_preloadLink">This link text is replaced with sc_imw_impp_starterText if text is missing</a>
    <button id="sc_imw_preloadButton">This button text is replaced with sc_imw_impp_starterText if text is missing</button>
    -->
          
    <!-- Script to set up images -->
    <script src="scWidget_InteractiveImageMap.js" type="text/javascript"></script>
    <script>sc_imw_Preload(["sc_imw_imgs/sc_imw_testingRoom1.png, sc_imw_imgs/sc_imw_testingRoom2.png"]);</script>
    ------------------------------------------------------------------------------------------ End HTML Code
    
    --------------------------------------
    
    PLUGINS INCLUDED INSIDE THIS SCRIPT, CUSTOMISED FOR IMW:
    -> Image Preloader
    -> Responsive Image Maps (non-functional in IE / Opera Mini: https://caniuse.com/resizeobserver)
    
    Plugins inside this script are non-intrusive and will not interact with elements that aren't given 
      the correct id. You can turn them off by setting the following variables to false:
      - sc_imw_impp (Image Preloader)
      - sc_imw_rimp (Responsive Image Maps)
    
    --------------------------------------
    
    COMPATIBLE WITH THE FOLLOWING PLUGINS:
    -> Image Click to Enlarge Plugin 
      - (Will not enlarge on click if using "sc_icep_noEnlarge" as the class name for exceptions)
    -> On Click Accessibility Plugin
    
    --------------------------------------
    
    /‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾\  Looking for more tutorials, widgets, and plugins?       /‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾\  
   ｜  ❮‾ |\  /|  / ⎡‾‾  ｜  Get them at my personal website or LHClubhouse room   ｜  ❮‾ |\  /|  / ⎡‾‾  ｜
   ｜  _❯ | \/ | /  ⎣__  ｜   https://scribblemakes.com/code                       ｜  _❯ | \/ | /  ⎣__  ｜  
    \___________________/    https://lordhorse.neocities.org/office/home           \____________________/ 
        
    --------------------------------------
    
    For more information on this script:
     https://scribblemakes.com/code/development#sc_imw
      
--------------------------------------------------------------------------------------------------------- */

// FILL IN ANY VARIABLES BELOW IF YOU WANT TO CHANGE THEM FROM THE DEFAULT
// You will need to set the sc_imw_mapImageFolder if you are not using the default file structure

const sc_imw_mappedImageId = "sc_imw_mappedImage";  // Change this to your image's id
const sc_imw_mapAreasClass = "sc_imw_MapClass"; // Class you've given your area shapes
const sc_imw_mapImageFolder = "sc_imw_imgs"; // What folder you're storing your map images in, local OR absolute link

const sc_imw_settingPlaceholder = true; // Replace image map with placeholder when the screen's small?
const sc_imw_settingMinWidth = "550px"; // What width, or smaller, triggers placeholder
  const sc_imw_settingMinWidthWarn = true;  // true/false, display a warning message on a small screen?
  const sc_imw_settingMinWidthWarnMessage = "Your screen is too small to support the interactive map"; // Warning message to display

// Image Preloader Plugin Setup
var sc_imw_impp = true; // Set to false to deactivate the built-in Image Preloader
const sc_imw_impp_starter = "onload"; // Choose: "onload", "link", "button"
const sc_imw_impp_starterText = "Preload Images"; // What goes inside the link or button starter
const sc_imw_impp_style = "blackout"; // Choose: "blackout", "invisible"
const sc_imw_impp_loadText = "Loading Images..."; // Text that displays when loading
const sc_imw_impp_loadTotalText = "/" // What goes between the two progress numbers ("0 / 50" for 50 images)

// Responsive Image Maps Plugin Setup
var sc_imw_rimp = true; // Set to false to deactivate the built-in Image Map Resizer
const sc_imw_rimp_originalWidth = 1920; // Width of the image without CSS styling (file dimensions, the size it was mapped at)
const sc_imw_rimp_originalHeight = 1080; // Height of the image without CSS styling (file dimensions, the size it was mapped at)



// ---------------------------------------------------------------------------------------------------------
// ---------------------- DO NOT EDIT PAST THIS POINT UNLESS PROFICIENT IN JAVASCRIPT ----------------------
// ---------------------------------------------------------------------------------------------------------

// Set up mapped image
const sc_imw_mappedImage = document.getElementById(sc_imw_mappedImageId);


if (sc_imw_mappedImage) {  // Check if mapped image is present

  // Set up new images and area map information
  sc_imw_mappedImage.parentNode.tabIndex = 0;
  const sc_imw_mappedImageOverlay = document.createElement("img");
  const sc_imw_mappedAreas = document.getElementsByClassName(sc_imw_mapAreasClass);
  
  // Set up images to work with the script and the CSS
  sc_imw_mappedImage.classList.add("sc_icep_noEnlarge");
  sc_imw_MappedImageSetup(sc_imw_mappedImageOverlay, "Overlay");
  sc_imw_mappedImageOverlay.classList.add("sc_imw_imageOverlap");
  
  // Sets up placeholder images and text for small screens
  if (sc_imw_settingPlaceholder) {  // Adds placeholder if setting is true
    const sc_imw_mappedImagePlaceholder = document.createElement("img");
    sc_imw_MappedImageSetup(sc_imw_mappedImagePlaceholder, "Placeholder");
    sc_imw_mappedImagePlaceholder.alt = sc_imw_mappedImage.alt;
    if (sc_imw_settingMinWidthWarn) { // Adds screen size warning if true
      const sc_imw_mappedImagePlaceholderMessage = document.createElement("div");
      sc_imw_mappedImagePlaceholderMessage.id = "sc_imw_mappedImagePlaceholderMessage";
      sc_imw_mappedImagePlaceholderMessage.innerText = sc_imw_settingMinWidthWarnMessage;
      sc_imw_mappedImagePlaceholder.parentNode.insertBefore(sc_imw_mappedImagePlaceholderMessage, sc_imw_mappedImagePlaceholder);
    }
  }
  
  // Sets up the map overlay, allowing for onhover animations
  // Add split to steal URL from HTML mouseenter to put into the focus listener
  for (sc_imw_i = 0; sc_imw_i < sc_imw_mappedAreas.length; sc_imw_i++) {
    // Find URL provided by onhover event for use with other events
    let sc_imw_mappedAreaHoverSrc = sc_imw_mappedImage.src;
    if (sc_imw_mappedAreas[sc_imw_i].onmouseenter) {
      sc_imw_mappedAreaHoverSrc = String(sc_imw_mappedAreas[sc_imw_i].onmouseenter);
      sc_imw_mappedAreaHoverSrc = sc_imw_mappedAreaHoverSrc.replace(/(`|')/g, '"');
      sc_imw_mappedAreaHoverSrc = sc_imw_mapImageFolder + "/" + sc_imw_mappedAreaHoverSrc.split('"')[1];
    }
    // Resets overlay when user stops hovering over map area
    sc_imw_mappedAreas[sc_imw_i].addEventListener('mouseleave', function(e) {
      sc_imw_mappedImageOverlay.src = sc_imw_mappedImage.src;
    });
    // Accessibility with keyboard
    sc_imw_mappedAreas[sc_imw_i].tabIndex = 0;  // lets area be focused on if it doesn't have a href
    // If focused on, change the overlay image
    sc_imw_mappedAreas[sc_imw_i].addEventListener('focus', function(e) {
      sc_imw_mappedImageOverlay.src = String(sc_imw_mappedAreaHoverSrc);
    });
    // if no longer focused, hide the overlay
    sc_imw_mappedAreas[sc_imw_i].addEventListener('blur', function(e) {
      sc_imw_mappedImageOverlay.src = sc_imw_mappedImage.src;
    });
  }

  // Necessary CSS for map function
  var sc_imw_cssPlaceholder = "";
  var sc_imw_cssPlaceholderWarn = "";
  if (sc_imw_settingMinWidthWarn) {
    sc_imw_cssPlaceholderWarn = `
        #sc_imw_mappedImagePlaceholderMessage  {
          display: block;
        }
    `;
  }
  if (sc_imw_settingPlaceholder){ // If placeholder is active
    sc_imw_cssPlaceholder = `
      @media only screen and (max-width: ` + sc_imw_settingMinWidth + `) {
        #sc_imw_container img {
          display: none;
        }
        #sc_imw_container #sc_imw_ImagePlaceholder  {
          display: block;
        }` +
        sc_imw_cssPlaceholderWarn +
      `}`;
  }
  var sc_imw_css = `
    #sc_imw_container {
      position: relative;
      box-sizing: border-box;
      overflow: hidden;
      width: 100%;
      height: auto;
      max-width: 100%;
    }
    #sc_imw_container area {
      cursor: pointer;
    }
    #sc_imw_container img {
      width: 100%;
      height: auto;
      max-height: 100%;
    }
    #sc_imw_ImagePlaceholder, #sc_imw_mappedImagePlaceholderMessage  {
      display: none;
    }
    /*#sc_imw_mappedImage {
      
    }*/
    .sc_imw_imageOverlap {
      position: absolute;
      display: block;
      top: 0;
      left: 0;
      background-size: cover;
      background-repeat: no-repeat;
      background-attachment: scroll;
      z-index: 10;
      pointer-events: none;
    }` + sc_imw_cssPlaceholder;
  var sc_imw_cssStyleSheet = document.createElement("style");
  sc_imw_cssStyleSheet.innerText = sc_imw_css;
  document.head.appendChild(sc_imw_cssStyleSheet);
    
  
} else {  // If the mapped image isn't on this screen, don't run any additional code
  sc_imw_rimp = false;
}

// Set up overlay & placeholder images to give them the right properties + CSS, then place them
function sc_imw_MappedImageSetup (sc_temp_inputImage, sc_temp_inputSuffix) {
  sc_temp_inputImage.id = "sc_imw_Image" + sc_temp_inputSuffix;
  sc_temp_inputImage.src = sc_imw_mappedImage.src;
  sc_temp_inputImage.style.backgroundImage = "url(" + sc_imw_mappedImage.src + ")";
  sc_temp_inputImage.tabIndex = -1;
  sc_temp_inputImage.classList.add("sc_icep_noEnlarge");
  sc_imw_mappedImage.parentNode.insertBefore(sc_temp_inputImage, sc_imw_mappedImage);
}

// On mouseenter function for map areas, changes overlay image
function sc_imw_AreaHover (sc_temp_inputURL) {
  document.getElementById("sc_imw_ImageOverlay").src = sc_imw_mapImageFolder + "/" + sc_temp_inputURL;
}


// MAP FUNCTIONS - CHANGING TO DIFFERENT MAPS
function sc_imw_changeArea(sc_temp_inputMapURL) { // Give function FILENAME.PNG, not full URL
  sc_imw_mappedImage.parentNode.focus();  // Move focus back to top for new area maps
  // Set up new images and new area map assignment
  sc_imw_mappedImage.src = sc_imw_mapImageFolder + "/" + sc_temp_inputMapURL;
  sc_imw_mappedImage.useMap = "#" + sc_temp_inputMapURL;
  document.getElementById("sc_imw_ImageOverlay").src = sc_imw_mapImageFolder + "/" + sc_temp_inputMapURL;
  document.getElementById("sc_imw_ImageOverlay").style.backgroundImage = "url(" + sc_imw_mapImageFolder + "/" + sc_temp_inputMapURL + ")";
  if (sc_imw_settingPlaceholder) {  // Change placeholder image if it exists
    document.getElementById("sc_imw_ImagePlaceholder").src = sc_imw_mapImageFolder + "/" + sc_temp_inputMapURL;
    document.getElementById("sc_imw_ImagePlaceholder").style.backgroundImage = "url(" + sc_imw_mapImageFolder + "/" + sc_temp_inputMapURL + ")";
  }
}


/* ---------------------------------------------------------------------------------------------------------

    SCRIBBLEMAKES PLUGIN
    ----------------------
    IMAGE PRELOADER PLUGIN
    ----------------------
    
    Customised to work only with the Interactive Map Widget script. To use this plugin on other images, 
      download it from one of these links:
    -- LINK HERE --
    
    If you have scPlugin_ImagePreloader.js installed and prefer to use that, you can disable this 
      plugin by turning sc_imw_impp from true to false (Set at the top of this script).
    
--------------------------------------------------------------------------------------------------------- */

function sc_imw_Preload (sc_temp_inputURLArray) { // USER calls this with background image URLs in array
  if (sc_imw_impp) {  // Only activates if plugin is allowed
    sc_imw_impp_PreloaderSetup(sc_temp_inputURLArray);
  }
}

function sc_imw_impp_PreloaderSetup (sc_temp_inputURLArray) { // Customised to preload all backgrounds and area map hover images
  // Style starter based on user choice
  switch (sc_imw_impp_starter) {
    
    case "onload":  // Load images on load
      sc_imw_impp_Preloader(sc_temp_inputURLArray);
      break;
      
    case "link": // Load images when a link is pressed, makes link if id doesn't exist
      if (document.getElementById("sc_imw_preloadLink")) {
        const sc_imw_preloadLink = document.getElementById("sc_imw_preloadLink");
        sc_imw_preloadLink.addEventListener('click', function(e) {
          sc_imw_impp_Preloader(sc_temp_inputURLArray);
        });
        if (sc_imw_preloadLink.innerText == "") {
          sc_imw_preloadLink.innerText = sc_imw_impp_starterText;
        }
      } else {
        const sc_imw_preloadLink = document.createElement("a");
        sc_imw_preloadLink.addEventListener('click', function(e) {
          sc_imw_impp_Preloader(sc_temp_inputURLArray);
        });
        sc_imw_preloadLink.id = "sc_imw_preloadLink";
        sc_imw_preloadLink.innerText = sc_imw_impp_starterText;
        sc_imw_mappedImage.parentNode.appendChild(sc_imw_preloadLink);
      }
      break;
      
    case "button":  // Load images when a button is pressed, makes button if id doesn't exist
      if (document.getElementById("sc_imw_preloadButton")) {
        const sc_imw_preloadButton = document.getElementById("sc_imw_preloadButton");
        sc_imw_preloadButton.addEventListener('click', function(e) {
          sc_imw_impp_Preloader(sc_temp_inputURLArray);
        });
        if (sc_imw_preloadButton.innerText == "") {
          sc_imw_preloadButton.innerText = sc_imw_impp_starterText;
        }
      } else {
        const sc_imw_preloadButton = document.createElement("button");
        sc_imw_preloadButton.addEventListener('click', function(e) {
          sc_imw_impp_Preloader(sc_temp_inputURLArray);
        });
        sc_imw_preloadButton.id = "sc_imw_preloadButton";
        sc_imw_preloadButton.innerText = sc_imw_impp_starterText;
        sc_imw_mappedImage.parentNode.appendChild(sc_imw_preloadButton);
      }
      break;
  }
  
  // Necessary CSS for preloader styles
  var sc_imw_impp_css = `
    #sc_imw_container a, #sc_imw_container button {
      display: block;
      width: 100%;
      text-align: center;
    }
    #sc_imw_preloadLink, #sc_imw_preloadButton {
      cursor: pointer;
    }
    .sc_imw_impp_blackout {
      display: block;
      position: absolute;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      background-color: black;
      color: white;
      text-align: center;
      z-index: 12;
    }
    .sc_imw_impp_blackout span {
      display: block;
      position: absolute;
      top: 50%;
      left: 50%;
      transform: translate(-50%,-50%);
    }
    .sc_imw_impp_blackoutLoadingImage {
      display: block;
      position: absolute;
      left: 0;
      top: 0;
      z-index: -9999;
    }`;
  var sc_imw_impp_cssStyleSheet = document.createElement("style");
  sc_imw_impp_cssStyleSheet.innerText = sc_imw_impp_css;
  document.head.appendChild(sc_imw_impp_cssStyleSheet);
}


var sc_imw_impp_totalImagesLoaded = 0;
var sc_imw_impp_totalImages = 0;
function sc_imw_impp_Preloader (sc_temp_inputURLArray) {  // Load Images
  
  // Get elements needed
  const sc_imw_impp_mapAreas = document.getElementsByClassName(sc_imw_mapAreasClass);
  var sc_imw_impp_mapAreasImg = [];
  const sc_imw_impp_mapContainer = sc_imw_mappedImage.parentNode;
  const sc_imw_impp_mapBGs = sc_temp_inputURLArray;
  
  // Add split to steal URL from HTML mouseenter to put into the preloader
  for (sc_imw_i = 0; sc_imw_i < sc_imw_impp_mapAreas.length; sc_imw_i++) {
    if (sc_imw_impp_mapAreas[sc_imw_i].onmouseenter) {
      sc_imw_impp_mapAreasImg.push(sc_imw_mapImageFolder + "/" + String(sc_imw_impp_mapAreas[sc_imw_i].onmouseenter).replace(/(`|')/g, '"').split('"')[1]);
    }
  }
  
  // Set loading check and text
  sc_imw_impp_totalImages = sc_imw_impp_mapAreasImg.length + sc_imw_impp_mapBGs.length;
  sc_imw_impp_loadObject = document.createElement("div");
  sc_imw_impp_loadObject.id = "sc_imw_impp_loadObject";
  sc_imw_impp_loadObjectText = document.createElement("span");
  sc_imw_impp_loadObjectText.id = "sc_imw_impp_loadObjectText";
  sc_imw_impp_loadObjectText.innerHTML = sc_imw_impp_loadText + "<br>" + sc_imw_impp_totalImagesLoaded + " " + sc_imw_impp_loadTotalText + " " + sc_imw_impp_totalImages;
  sc_imw_impp_mapContainer.appendChild(sc_imw_impp_loadObject);
  sc_imw_impp_loadObject.appendChild(sc_imw_impp_loadObjectText);
  
  // Style map based on user choice while loading
  switch (sc_imw_impp_style) {
    case "blackout":
      sc_imw_impp_loadObject.classList.add("sc_imw_impp_blackout");
      break;
    case "invisible":
      sc_imw_impp_loadObject.style.display = "none";
      break;
  }
  
  // Preload images
  for (sc_imw_i = 0; sc_imw_i < sc_imw_impp_mapAreasImg.length; sc_imw_i++) { // Load all the overlays
    let sc_imw_impp_loadingImage = document.createElement("img");
    sc_imw_impp_loadingImage.classList.add("sc_imw_impp_" + sc_imw_impp_style + "LoadingImage");
    sc_imw_impp_loadingImage.src = sc_imw_impp_mapAreasImg[sc_imw_i];
    sc_imw_impp_mapContainer.appendChild(sc_imw_impp_loadingImage);
    sc_imw_impp_loadingImage.onLoad = sc_imw_impp_PreloaderCheck(sc_imw_impp_loadingImage, sc_imw_i);
  }
  // Preload BGs
  for (sc_imw_i = 0; sc_imw_i < sc_imw_impp_mapBGs.length; sc_imw_i++) {  // Load all the backgrounds
    let sc_imw_impp_loadingImage = document.createElement("img");
    sc_imw_impp_loadingImage.classList.add("sc_imw_impp_" + sc_imw_impp_style + "LoadingImage");
    sc_imw_impp_loadingImage.src = sc_imw_impp_mapBGs[sc_imw_i];
    sc_imw_impp_mapContainer.appendChild(sc_imw_impp_loadingImage);
    sc_imw_impp_loadingImage.onLoad = sc_imw_impp_PreloaderCheck(sc_imw_impp_loadingImage, sc_imw_i + sc_imw_impp_mapAreasImg.length);
  }
}

var sc_imw_impp_loadingImageIntervals = [];
function sc_imw_impp_PreloaderCheck (sc_imw_impp_loadingImage, sc_imw_i) {  // Check if loading is done
  sc_imw_impp_loadingImageIntervals[sc_imw_i] = setInterval(function() {
      if(sc_imw_impp_loadingImage.complete){
        sc_imw_impp_totalImagesLoaded++;
        let sc_imw_impp_loadImageTextObject = document.getElementById("sc_imw_impp_loadObjectText");
        sc_imw_impp_loadImageTextObject.innerHTML = sc_imw_impp_loadText + "<br>" + sc_imw_impp_totalImagesLoaded + " " + sc_imw_impp_loadTotalText + " " + sc_imw_impp_totalImages;
        sc_imw_impp_loadingImage.parentNode.removeChild(sc_imw_impp_loadingImage);
        if(sc_imw_impp_totalImagesLoaded == sc_imw_impp_totalImages){
          sc_imw_impp_totalImagesLoaded = 0;
          document.getElementById("sc_imw_impp_loadObject").parentNode.removeChild(document.getElementById("sc_imw_impp_loadObject"));
        }
        clearInterval(sc_imw_impp_loadingImageIntervals[sc_imw_i]);
      }
    }, 500);
}


/* ---------------------------------------------------------------------------------------------------------

    SCRIBBLEMAKES PLUGIN
    ----------------------------
    RESPONSIVE IMAGE MAPS PLUGIN
    ----------------------------
    
    Customised to work only with the Interactive Map Widget script. To use this plugin on other 
      interactive maps, download it from one of these links:
    -- LINK HERE --
    
    If you have scPlugin_InteractiveMapResizer.js installed and prefer to use that, you can disable this 
      plugin by turning sc_imw_rimp from true to false (Set at the top of this script).
    
--------------------------------------------------------------------------------------------------------- */

if (sc_imw_rimp) {
  // Sets up object variables and multiplication amount
  const sc_imw_rimp_mappedImage = document.getElementById(sc_imw_mappedImageId);
  const sc_imw_rimp_mapAreas = document.getElementsByClassName(sc_imw_mapAreasClass);
  var sc_imw_rimp_multiplyXBy = 1;
  var sc_imw_rimp_multiplyYBy = 1;
  var sc_imw_rimp_previousWidth = sc_imw_rimp_originalWidth;
  var sc_imw_rimp_previousHeight = sc_imw_rimp_originalHeight;
  // Stores original coordinates to avoid * 0 deletion
  var sc_imw_rimp_mapAreasOGCoords = [];
  for (sc_imw_rimp_i = 0; sc_imw_rimp_i < sc_imw_rimp_mapAreas.length; sc_imw_rimp_i++){
    sc_imw_rimp_mapAreasOGCoords.push(sc_imw_rimp_mapAreas[sc_imw_rimp_i].coords);
  }
  
  // Makes observer that will watch for resizing
  const sc_imw_rimp_mappedImageObserver = new ResizeObserver(entries =>{
      entries.forEach(entry => {
        
        // Finds how much to multiple the coords by
        sc_imw_rimp_multiplyXBy = entry.contentRect.width / sc_imw_rimp_previousWidth;
        sc_imw_rimp_multiplyYBy = entry.contentRect.height / sc_imw_rimp_previousHeight;
        // Saves size to compare to next time
        sc_imw_rimp_previousWidth = entry.contentRect.width; sc_imw_rimp_previousHeight = entry.contentRect.height;
        // If image is not visible, stops script from dividing by 0
        if (entry.contentRect.width == 0 || entry.contentRect.height == 0){
          sc_imw_rimp_previousWidth = sc_imw_rimp_originalWidth;
          sc_imw_rimp_previousHeight = sc_imw_rimp_originalHeight;
        }
        
        // Replaces the coords with the appropriate amount
        for (sc_imw_rimp_i = 0; sc_imw_rimp_i < sc_imw_rimp_mapAreas.length; sc_imw_rimp_i++) {
          // If coords stuck at 0,0, reset to original
          let sc_imw_rimp_coordCheckSumY = 0, sc_imw_rimp_coordCheckSumX = 0;
          for (sc_imw_rimp_ii = 0; sc_imw_rimp_ii < sc_imw_rimp_mapAreas[sc_imw_rimp_i].coords.split(",").length; sc_imw_rimp_ii++) {
            if (sc_imw_rimp_ii % 2 == 0) {
              sc_imw_rimp_coordCheckSumX += parseFloat(sc_imw_rimp_mapAreas[sc_imw_rimp_i].coords.split(",")[sc_imw_rimp_ii]);
            } else {
              sc_imw_rimp_coordCheckSumY += parseFloat(sc_imw_rimp_mapAreas[sc_imw_rimp_i].coords.split(",")[sc_imw_rimp_ii]);
            }
          }
          if (sc_imw_rimp_coordCheckSumY == 0 || sc_imw_rimp_coordCheckSumX == 0) {
            sc_imw_rimp_mapAreas[sc_imw_rimp_i].coords = sc_imw_rimp_mapAreasOGCoords[sc_imw_rimp_i];
          }
          let sc_imw_rimp_coordHolder = sc_imw_rimp_mapAreas[sc_imw_rimp_i].coords.split(",");  // Splits up coords for x & y
          // Go through the coords and correct them
          for (sc_imw_rimp_ii = 0; sc_imw_rimp_ii < sc_imw_rimp_coordHolder.length; sc_imw_rimp_ii++){
            if (sc_imw_rimp_ii % 2 == 0) { // Finds X coords
              sc_imw_rimp_coordHolder[sc_imw_rimp_ii] = sc_imw_rimp_coordHolder[sc_imw_rimp_ii] * sc_imw_rimp_multiplyXBy;
            } else { // Finds Y coords
              sc_imw_rimp_coordHolder[sc_imw_rimp_ii] = sc_imw_rimp_coordHolder[sc_imw_rimp_ii] * sc_imw_rimp_multiplyYBy;
            }
          }
          sc_imw_rimp_mapAreas[sc_imw_rimp_i].coords = sc_imw_rimp_coordHolder.join(","); // Set area map's coords with new ones
        }
      });
    });
    
  // Tell observer to watch mapped image
  sc_imw_rimp_mappedImageObserver.observe(sc_imw_rimp_mappedImage);
}

